@@ -1,10 +1,11 @@
+from pykka.actor import ThreadingActor
+
 from mopidy.mixers.base import BaseMixer
 
-class DummyMixer(BaseMixer):
+class DummyMixer(ThreadingActor, BaseMixer):
     """Mixer which just stores and reports the chosen volume."""
 
-    def __init__(self, *args, **kwargs):
-        super(DummyMixer, self).__init__(*args, **kwargs)
+    def __init__(self):
         self._volume = None
 
     def _get_volume(self):
