@@ -1,13 +1,17 @@
 import logging
 import logging.handlers
+import platform
 
-from mopidy import settings
+from mopidy import get_version, get_platform, get_python, settings
 
 def setup_logging(verbosity_level, save_debug_log):
     setup_root_logger()
     setup_console_logging(verbosity_level)
     if save_debug_log:
         setup_debug_logging_to_file()
+    logger = logging.getLogger('mopidy.utils.log')
+    logger.info(u'Starting Mopidy %s on %s %s',
+        get_version(), get_platform(), get_python())
 
 def setup_root_logger():
     root = logging.getLogger('')
