@@ -1,7 +1,9 @@
 import os
 
 try: # 2.7
+    # pylint: disable = E0611,F0401
     from unittest.case import SkipTest
+    # pylint: enable = E0611,F0401
 except ImportError:
     try: # Nose
         from nose.plugins.skip import SkipTest
@@ -14,9 +16,9 @@ from mopidy import settings
 # Nuke any local settings to ensure same test env all over
 settings.local.clear()
 
-def data_folder(name):
-    folder = os.path.dirname(__file__)
-    folder = os.path.join(folder, 'data')
-    folder = os.path.abspath(folder)
-    return os.path.join(folder, name)
+def path_to_data_dir(name):
+    path = os.path.dirname(__file__)
+    path = os.path.join(path, 'data')
+    path = os.path.abspath(path)
+    return os.path.join(path, name)
 
